@@ -8,6 +8,7 @@ import mosaik_api
 from midas.util.dict_util import strtobool, update
 from midas.util.logging import set_and_init_logger
 from midas.util.print_format import mformat
+from midas.util.runtime_config import RuntimeConfig
 
 from .meta import META
 from .model.constrainted import ConstraintedGrid
@@ -37,6 +38,7 @@ class PandapowerSimulator(mosaik_api.Simulator):
         self.plotter_cfg = dict()
         self.plotter = None
         self._sim_time: int = 0
+        self.key_value_logs: bool
 
     def init(self, sid, **sim_params):
         """Called exactly ones after the simulator has been started.
@@ -54,6 +56,7 @@ class PandapowerSimulator(mosaik_api.Simulator):
             The meta dict (set by mosaik_api.Simulator)
 
         """
+        self.sid = sid
         if "step_size" not in sim_params:
             LOG.debug(
                 "Param *step_size* not provided. "
@@ -75,6 +78,10 @@ class PandapowerSimulator(mosaik_api.Simulator):
                 "plot_path", "_plots"
             )
 
+        self.key_value_logs = sim_params.get(
+            "key_value_logs", RuntimeConfig().misc.get("key_value_logs", False)
+        )
+
         return self.meta
 
     def create(self, num, model, **model_params):
@@ -167,7 +174,10 @@ class PandapowerSimulator(mosaik_api.Simulator):
 
         """
         self._sim_time = time
-        LOG.debug("At step %d received inputs %s", time, mformat(inputs))
+        if self.key_value_logs:
+            LOG.info(inputs)
+        else:
+            LOG.debug("At step %d received inputs %s", time, mformat(inputs))
 
         for eid, attrs in inputs.items():
             gidx = eid.split("-")[0]
@@ -238,14 +248,23 @@ class PandapowerSimulator(mosaik_api.Simulator):
                     ] = self.models[eid].to_json()
 
                 continue
-
+            log_msg = {
+                "id": f"{self.sid}_{eid}",
+                "name": eid,
+                "type": eid.split("-")[1],
+            }
             for attr in attrs:
                 val = self.cache[eid][attr]
                 data.setdefault(eid, dict())[attr] = val
+                log_msg[attr] = val
 
-        LOG.debug(
-            "At step %d gathered outputs %s", self._sim_time, mformat(data)
-        )
+            if self.key_value_logs:
+                LOG.info(log_msg)
+
+        if not self.key_value_logs:
+            LOG.debug(
+                "At step %d gathered outputs %s", self._sim_time, mformat(data)
+            )
         update(data, grid_json)
         return data
 
